"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.createGraphqlClient = createGraphqlClient;
exports.createRestClient = createRestClient;

var _nodeFetch = _interopRequireDefault(require("node-fetch"));

var _errors = require("./errors");

const MAX_BACKOFF_MILLISECONDS = 60000; // TODO Update logic for handling errors (500 specifically) and update the
// "hacky" code in createRestClient

function createGraphqlClient(options) {
  const url = `https://${options.storeUrl}/admin/api/2021-07/graphql.json`;

  async function graphqlFetch(query, variables, retries = 0) {
    const response = await (0, _nodeFetch.default)(url, {
      method: `POST`,
      headers: {
        "Content-Type": `application/json`,
        "X-Shopify-Access-Token": options.password
      },
      body: JSON.stringify({
        query,
        variables
      })
    });

    if (!response.ok) {
      const waitTime = 2 ** (retries + 1) + 500;

      if (response.status >= 500 && waitTime < MAX_BACKOFF_MILLISECONDS) {
        await new Promise(resolve => setTimeout(resolve, waitTime));
        return graphqlFetch(query, variables, retries + 1);
      }

      throw new _errors.HttpError(response);
    }

    const json = await response.json();
    return json.data;
  }

  return {
    request: graphqlFetch
  };
}

function createRestClient(options) {
  const baseUrl = `https://${options.storeUrl}/admin/api/2021-01`;

  async function shopifyFetch(path, fetchOptions = {
    headers: {
      "X-Shopify-Access-Token": options.password
    }
  }, retries = 3) {
    /**
     * This is kind of a hack, but...
     *
     * We do this because although callers will use a relative path,
     * some responses might have pagination links that get fed back
     * to shopifyFetch to retrieve the next page. Those links are
     * absolute URLs so we account for both, but not in a very robust
     * fashion.
     */
    const url = path.includes(options.storeUrl) ? path : `${baseUrl}${path}`;
    const resp = await (0, _nodeFetch.default)(url, fetchOptions);

    if (!resp.ok && retries > 0 && resp.status === 429) {
      // rate limit
      const retryAfter = parseFloat(resp.headers.get(`Retry-After`) || ``);
      await new Promise(resolve => setTimeout(resolve, retryAfter));
      return shopifyFetch(path, fetchOptions, retries - 1);
    }

    return resp;
  }

  return {
    request: async path => shopifyFetch(path)
  };
}
//# sourceMappingURL=clients.js.map