"use strict";

exports.__esModule = true;
exports.createResolvers = createResolvers;

var _graphqlUtils = require("gatsby-plugin-image/graphql-utils");

var _shopifyTypes = require("./shopify-types");

var _resolveGatsbyImageData = require("./resolve-gatsby-image-data");

function createResolvers(gatsbyApi, pluginOptions) {
  const {
    createResolvers,
    cache
  } = gatsbyApi;
  const {
    downloadImages,
    typePrefix,
    shopifyConnections: connections
  } = pluginOptions;

  if (!downloadImages) {
    createResolvers({
      [`${typePrefix}ShopifyImage`]: {
        gatsbyImageData: { ...(0, _graphqlUtils.getGatsbyImageFieldConfig)((0, _resolveGatsbyImageData.makeResolveGatsbyImageData)(cache)),
          type: `JSON` // Because gatsbyImageData will be undefined for GIFs it must be optional

        }
      }
    });
  } // Attach the metafield resolver to all types with a metafields field


  for (const [type, value] of Object.entries(_shopifyTypes.shopifyTypes)) {
    var _value$coupledNodeFie;

    if ((_value$coupledNodeFie = value.coupledNodeFields) !== null && _value$coupledNodeFie !== void 0 && _value$coupledNodeFie.includes(`metafields___NODE`)) {
      // Only include the resolver if the type is included in the build
      if (!value.optionalKey || connections.includes(value.optionalKey)) {
        createResolvers({
          [`${typePrefix}Shopify${type}`]: {
            metafield: {
              resolve: async (source, args, context) => context.nodeModel.findOne({
                type: `${typePrefix}ShopifyMetafield`,
                query: {
                  filter: {
                    key: {
                      eq: args.key
                    },
                    namespace: {
                      eq: args.namespace
                    },
                    id: {
                      in: source.metafields___NODE
                    }
                  }
                }
              })
            }
          }
        });
      }
    }
  }
}
//# sourceMappingURL=create-resolvers.js.map