"use strict";

exports.__esModule = true;
exports.createSchemaCustomization = createSchemaCustomization;

var _collectionType = require("./type-builders/collection-type");

var _commonType = require("./type-builders/common-type");

var _locationType = require("./type-builders/location-type");

var _mediaType = require("./type-builders/media-type");

var _metafieldType = require("./type-builders/metafield-type");

var _orderType = require("./type-builders/order-type");

var _productType = require("./type-builders/product-type");

var _productVariantType = require("./type-builders/product-variant-type");

function createSchemaCustomization(gatsbyApi, pluginOptions) {
  const {
    actions
  } = gatsbyApi;
  const {
    downloadImages,
    shopifyConnections: connections,
    typePrefix
  } = pluginOptions;
  const prefix = `${typePrefix}Shopify`;
  const typeDefs = [(0, _commonType.commonTypeBuilder)(prefix), (0, _mediaType.mediaTypeBuilder)(prefix), (0, _metafieldType.metafieldTypeBuilder)(prefix), (0, _productType.productTypeBuilder)(prefix), (0, _productVariantType.productVariantTypeBuilder)(prefix)];

  if (connections.includes(`collections`)) {
    typeDefs.push((0, _collectionType.collectionTypeBuilder)(prefix));
  }

  if (connections.includes(`locations`)) {
    typeDefs.push((0, _locationType.locationTypeBuilder)(prefix));
  }

  if (connections.includes(`orders`)) {
    typeDefs.push((0, _orderType.orderTypeBuilder)(prefix));
  }

  if (downloadImages) {
    typeDefs.push(`
      extend type ${prefix}Image {
        localFile: File @link(from: "localFile___NODE", by: "id")
      }
    `);
  }

  actions.createTypes(typeDefs);
}
//# sourceMappingURL=create-schema-customization.js.map