"use strict";

exports.__esModule = true;
exports.ERROR_MAP = void 0;

var _shiftLeft = require("shift-left");

var _errors = require("./errors");

const getErrorText = context => context.sourceMessage;

const ERROR_MAP = {
  [_errors.pluginErrorCodes.bulkOperationFailed]: {
    text: getErrorText,
    level: `ERROR`,
    category: `USER`
  },
  [_errors.pluginErrorCodes.apiConflict]: {
    text: () => (0, _shiftLeft.shiftLeft)`
    Your operation was canceled. You might have another production site for this Shopify store.

    Shopify only allows one bulk operation at a time for a given shop, so we recommend that you
    avoid having two production sites that point to the same Shopify store.

    If the duplication is intentional, please wait for the other operation to finish before trying
    again. Otherwise, consider deleting the other site or pointing it to a test store instead.
  `,
    level: `ERROR`,
    category: `USER`
  },

  /**
   * If we don't know what it is, we haven't done our due
   * diligence to handle it explicitly. That means it's our
   * fault, so THIRD_PARTY indicates us, the plugin authors.
   */
  [_errors.pluginErrorCodes.unknownSourcingFailure]: {
    text: getErrorText,
    level: `ERROR`,
    category: `THIRD_PARTY`
  },
  [_errors.pluginErrorCodes.unknownApiError]: {
    text: getErrorText,
    level: `ERROR`,
    category: `THIRD_PARTY`
  }
};
exports.ERROR_MAP = ERROR_MAP;
//# sourceMappingURL=error-map.js.map