"use strict";

exports.__esModule = true;
exports.sourceNodes = exports.pluginOptionsSchema = exports.createSchemaCustomization = exports.createResolvers = void 0;

var _errorMap = require("./error-map");

var _sourceNodes = require("./source-nodes");

exports.sourceNodes = _sourceNodes.sourceNodes;

var _createResolvers = require("./create-resolvers");

exports.createResolvers = _createResolvers.createResolvers;

var _pluginOptionsSchema = require("./plugin-options-schema");

exports.pluginOptionsSchema = _pluginOptionsSchema.pluginOptionsSchema;

var _createSchemaCustomization = require("./create-schema-customization");

exports.createSchemaCustomization = _createSchemaCustomization.createSchemaCustomization;

const initializePlugin = ({
  reporter
}) => {
  reporter.setErrorMap(_errorMap.ERROR_MAP);
};

let coreSupportsOnPluginInit;

try {
  const {
    isGatsbyNodeLifecycleSupported
  } = require(`gatsby-plugin-utils`);

  if (isGatsbyNodeLifecycleSupported(`onPluginInit`)) {
    coreSupportsOnPluginInit = `stable`;
  } else if (isGatsbyNodeLifecycleSupported(`unstable_onPluginInit`)) {
    coreSupportsOnPluginInit = `unstable`;
  }
} catch (e) {
  console.error(`Could not check if Gatsby supports onPluginInit lifecycle`);
}

if (coreSupportsOnPluginInit === `unstable`) {
  // need to conditionally export otherwise it throws an error for older versions
  exports.unstable_onPluginInit = initializePlugin;
} else if (coreSupportsOnPluginInit === `stable`) {
  exports.onPluginInit = initializePlugin;
} else {
  exports.onPreInit = initializePlugin;
}
//# sourceMappingURL=gatsby-node.js.map