"use strict";

exports.__esModule = true;
exports.processBulkResults = processBulkResults;

var _shopifyTypes = require("./shopify-types");

var _helpers = require("./helpers");

function isNode(result) {
  const keys = Object.keys(result);
  return Boolean(result.shopifyId && !(keys.length === 2 && result.__parentId && result.shopifyId));
}

async function processBulkResults(gatsbyApi, pluginOptions, results) {
  let nodeCount = 0;
  const promises = [];
  const children = {};

  for (let i = results.length - 1; i >= 0; i -= 1) {
    const result = (0, _helpers.decorateBulkObject)(results[i]);
    /**
     * @todo detect the following different as JSON.stringify order is not deterministic
     */

    const resultIsNode = isNode(result);

    if (resultIsNode) {
      const type = (0, _helpers.parseShopifyId)(result.shopifyId)[1];
      const imageFields = _shopifyTypes.shopifyTypes[type].imageFields;
      const referenceFields = _shopifyTypes.shopifyTypes[type].referenceFields; // Only increment for parent nodes

      if (!result.__parentId) nodeCount++; // Attach reference fields

      if (referenceFields) {
        for (const referenceField of referenceFields) {
          result[referenceField] = [];
        }
      } // Attach children references / objects


      if (children[result.shopifyId]) {
        for (const child of children[result.shopifyId]) {
          const childType = typeof child === `string` ? (0, _helpers.parseShopifyId)(child)[1] : child.__typename;
          const field = _shopifyTypes.shopifyTypes[childType].key;

          if (field) {
            result[field] = [typeof child === `string` ? (0, _helpers.createNodeId)(child, gatsbyApi, pluginOptions) : child, ...(result[field] || [])];
          } else {
            throw new Error(`There is no shopifyType for child type: ${childType}`);
          }
        }
      }

      if (!(0, _helpers.isShopifyId)(result.shopifyId)) {
        throw new Error(`Expected an ID in the format gid://shopify/<typename>/<id>`);
      }

      const node = { ...result,
        id: (0, _helpers.createNodeId)(result.shopifyId, gatsbyApi, pluginOptions),
        internal: {
          type: `${pluginOptions.typePrefix}Shopify${type}`,
          contentDigest: gatsbyApi.createContentDigest(result)
        }
      };

      if (pluginOptions.downloadImages && imageFields) {
        promises.push((0, _helpers.processShopifyImages)(gatsbyApi, node).then(() => gatsbyApi.actions.createNode(node)));
      } else {
        gatsbyApi.actions.createNode(node);
      }
    } // If the object is a child store the reference


    if (result.__parentId) {
      children[result.__parentId] = [...(children[result.__parentId] || []), result.shopifyId || result];
    }
  }

  await Promise.all(promises);
  return nodeCount;
}
//# sourceMappingURL=process-bulk-results.js.map