"use strict";

exports.__esModule = true;
exports.sourceNodes = sourceNodes;

var _updateCache = require("./update-cache");

var _createOperations = require("./create-operations");

var _sourceFromOperation = require("./source-from-operation");

var _helpers = require("./helpers");

async function sourceNodes(gatsbyApi, pluginOptions) {
  const {
    shopifyConnections: connections
  } = pluginOptions;
  gatsbyApi.reporter.info(`Running ${(0, _helpers.isPriorityBuild)(pluginOptions) ? `` : `non-`}priority queries`);
  const currentBuildTime = Date.now();
  const lastBuildTime = (0, _helpers.getLastBuildTime)(gatsbyApi, pluginOptions);
  const {
    productsOperation,
    productVariantsOperation,
    ordersOperation,
    collectionsOperation,
    locationsOperation,
    finishLastOperation,
    completedOperation,
    cancelOperationInProgress
  } = (0, _createOperations.createOperations)(gatsbyApi, pluginOptions, lastBuildTime);
  const sourceFromOperation = (0, _sourceFromOperation.makeSourceFromOperation)(finishLastOperation, completedOperation, cancelOperationInProgress, gatsbyApi, pluginOptions, lastBuildTime);
  const operations = [productsOperation, productVariantsOperation];

  if (connections.includes(`orders`)) {
    operations.push(ordersOperation);
  }

  if (connections.includes(`collections`)) {
    operations.push(collectionsOperation);
  }

  if (connections.includes(`locations`)) {
    operations.push(locationsOperation);
  }

  for (const op of operations) {
    await sourceFromOperation(op);
  }

  if (lastBuildTime) {
    await (0, _updateCache.updateCache)(gatsbyApi, pluginOptions, lastBuildTime);
  }

  (0, _helpers.setLastBuildTime)(gatsbyApi, pluginOptions, currentBuildTime);
}
//# sourceMappingURL=source-nodes.js.map